@@ -61,14 +61,15 @@
 
 (defmacro define-purpose-list-checker (name entry-pred)
   "Create a function named NAME to check the content of a list.
-The generated function receives parameter OBJ, and checks that it is a
-list and each entry in it satisifies ENTRY-PRED."
+The generated function receives parameter OBJ, and checks that it
+is a list and each entry in it satisifies ENTRY-PRED."
   (declare (indent defun) (debug (&define name function-form)))
-  `(defun ,name (obj)
-     ,(format "Check that OBJ is a list, and each entry in it satisifies %s." entry-pred)
-     (and (listp obj)
-          (cl-loop for entry in obj
-                   always (funcall ,entry-pred entry)))))
+  (let ((pred (replace-regexp-in-string "#'" "\\\\='" (format "%s" entry-pred))))
+    `(defun ,name (obj)
+       ,(format "If OBJ is a list and every entry satisifies %s." pred)
+       (and (listp obj)
+            (cl-loop for entry in obj
+                     always (funcall ,entry-pred entry))))))
 
 (defun purpose-non-nil-symbol-p (obj)
   "Check that OBJ is a symbol and not nil."
@@ -137,9 +138,9 @@ If you set this variable in elisp-code, you should call the function
   :group 'purpose
   :type '(alist :key-type (symbol :tag "major mode")
                 :value-type (symbol :tag "purpose"))
-  :set #'(lambda (symbol value)
-           (prog1 (set-default symbol value)
-             (purpose-compile-user-configuration)))
+  :set (lambda (symbol value)
+         (prog1 (set-default symbol value)
+           (purpose-compile-user-configuration)))
   :initialize 'custom-initialize-default
   :package-version '(window-purpose . "1.2"))
 
@@ -151,9 +152,9 @@ If you set this variable in elisp-code, you should call the function
   :group 'purpose
   :type '(alist :key-type (string :tag "name")
                 :value-type (symbol :tag "purpose"))
-  :set #'(lambda (symbol value)
-           (prog1 (set-default symbol value)
-             (purpose-compile-user-configuration)))
+  :set (lambda (symbol value)
+         (prog1 (set-default symbol value)
+           (purpose-compile-user-configuration)))
   :initialize 'custom-initialize-default
   :package-version '(window-purpose . "1.2"))
 
@@ -165,9 +166,9 @@ If you set this variable in elisp-code, you should call the function
   :group 'purpose
   :type '(alist :key-type (string :tag "regexp")
                 :value-type (symbol :tag "purpose"))
-  :set #'(lambda (symbol value)
-           (prog1 (set-default symbol value)
-             (purpose-compile-user-configuration)))
+  :set (lambda (symbol value)
+         (prog1 (set-default symbol value)
+           (purpose-compile-user-configuration)))
   :initialize 'custom-initialize-default
   :package-version '(window-purpose . "1.2"))
 
@@ -175,10 +176,10 @@ If you set this variable in elisp-code, you should call the function
   "A plist containing `purpose-conf' objects.
 An example of `purpose-extended-configuration':
  (list :python (purpose-conf
-                :mode-purposes '((python-mode . python)
+                :mode-purposes \\='((python-mode . python)
                                 (python-inferior-mode . interpreter)))
        :popups (purpose-conf
-                :mode-purposes '((help-mode . right)
+                :mode-purposes \\='((help-mode . right)
                                  (occur-mode . bottom)
                                  (grep-mode . bottom))))")
 
@@ -238,8 +239,8 @@ The contents of this variable are generated by
 TABLE is cleared before filling it, unless DONT-CLEAR is non-nil."
   (unless dont-clear
     (clrhash table))
-  (mapc #'(lambda (entry)
-            (puthash (car entry) (cdr entry) table))
+  (mapc (lambda (entry)
+          (puthash (car entry) (cdr entry) table))
         alist))
 
 (defun purpose--set-and-compile-configuration (symbol value)
@@ -272,16 +273,16 @@ Fill `purpose--extended-mode-purposes',
   (purpose--fill-hash purpose--extended-regexp-purposes nil)
 
   ;; populate compiled purposes
-  (mapc #'(lambda (extension-config)
-            (purpose--fill-hash purpose--extended-mode-purposes
-                                (slot-value extension-config :mode-purposes)
-                                t)
-            (purpose--fill-hash purpose--extended-name-purposes
-                                (slot-value extension-config :name-purposes)
-                                t)
-            (purpose--fill-hash purpose--extended-regexp-purposes
-                                (slot-value extension-config :regexp-purposes)
-                                t))
+  (mapc (lambda (extension-config)
+          (purpose--fill-hash purpose--extended-mode-purposes
+                              (slot-value extension-config 'mode-purposes)
+                              t)
+          (purpose--fill-hash purpose--extended-name-purposes
+                              (slot-value extension-config 'name-purposes)
+                              t)
+          (purpose--fill-hash purpose--extended-regexp-purposes
+                              (slot-value extension-config 'regexp-purposes)
+                              t))
         (delq nil (purpose-plist-values purpose-extended-configuration))))
 
 (defun purpose-compile-default-configuration ()
@@ -321,12 +322,12 @@ Fill `purpose--extended-mode-purposes',
   "Add purposes to a `purpose-conf' object.
 MODES, NAMES and REGEXPS must be valid configuration alists as described in
 `purpose-mode-alist-p', `purpose-name-alist-p' and `purpose-regexp-alist-p'."
-  (setf (slot-value config :mode-purposes)
-        (append modes (slot-value config :mode-purposes)))
-  (setf (slot-value config :name-purposes)
-        (append names (slot-value config :name-purposes)))
-  (setf (slot-value config :regexp-purposes)
-        (append regexps (slot-value config :regexp-purposes))))
+  (setf (slot-value config 'mode-purposes)
+        (append modes (slot-value config 'mode-purposes)))
+  (setf (slot-value config 'name-purposes)
+        (append names (slot-value config 'name-purposes)))
+  (setf (slot-value config 'regexp-purposes)
+        (append regexps (slot-value config 'regexp-purposes))))
 
 (cl-defmethod purpose-conf-remove-purposes ((config purpose-conf) modes names regexps)
   "Remove purposes from a `purpose-conf' object.
@@ -335,18 +336,18 @@ NAMES must be a list names.
 REGEXPS must be a list regexps."
   ;; let-bind before setq-ing, so we don't apply partial changes if one
   ;; of MODES, NAMES or REGEXPS is malformed
-  (let ((new-modes (cl-set-difference (slot-value config :mode-purposes) modes
+  (let ((new-modes (cl-set-difference (slot-value config 'mode-purposes) modes
                                       :test (lambda (entry mode)
                                               (eql (car entry) mode))))
-        (new-names (cl-set-difference (slot-value config :name-purposes) names
+        (new-names (cl-set-difference (slot-value config 'name-purposes) names
                                       :test (lambda (entry name)
                                               (string= (car entry) name))))
-        (new-regexps (cl-set-difference (slot-value config :regexp-purposes) regexps
+        (new-regexps (cl-set-difference (slot-value config 'regexp-purposes) regexps
                                         :test (lambda (entry regexp)
                                                 (string= (car entry) regexp)))))
-    (setf (slot-value config :mode-purposes) new-modes)
-    (setf (slot-value config :name-purposes) new-names)
-    (setf (slot-value config :regexp-purposes) new-regexps)))
+    (setf (slot-value config 'mode-purposes) new-modes)
+    (setf (slot-value config 'name-purposes) new-names)
+    (setf (slot-value config 'regexp-purposes) new-regexps)))
 
 ;;;###autoload
 (defun purpose-set-extension-configuration (ext-keyword config)
@@ -357,9 +358,8 @@ configuration.
 Example:
  (purpose-set-extension-configuration
      :python
-     (purpose-conf \"py\"
-                   :mode-purposes
-                   '((python-mode . python)
+     (purpose-conf :mode-purposes
+                   \\='((python-mode . python)
                      (inferior-python-mode . interpreter))))
 
 This function calls `purpose-compile-extended-configuration' when its
@@ -394,7 +394,7 @@ This function calls `purpose-compile-extended-configuration'.
 
 Example:
  (purpose-add-extension-purposes :python
-                                 :regexps '((\"\\.hy$\" . python)))"
+                                 :regexps \\='((\"\\.hy$\" . python)))"
   (let ((config (purpose-get-extension-configuration ext-keyword)))
     (unless config
       (user-error "Missing extension configuration: %s" ext-keyword))
@@ -410,8 +410,8 @@ This function calls `purpose-compile-extended-configuration'.
 
 Example:
  (purpose-remove-extension-purposes :python
-                                    :modes '(inferior-python-mode)
-                                    :regexps '(\"\\.hy$\"))"
+                                    :modes \\='(inferior-python-mode)
+                                    :regexps \\='(\"\\.hy$\"))"
   (let ((config (purpose-get-extension-configuration ext-keyword)))
     (unless config
       (user-error "Missing extension configuration: %s" ext-keyword))
@@ -428,10 +428,10 @@ This function calls `purpose-compile-user-configuration' to
 update user purposes.
 
 Example:
- (purpose-add-user-purposes :modes '((org-mode . org)
+ (purpose-add-user-purposes :modes \\='((org-mode . org)
                                      (help-mode . popup))
-                            :names '((\"*scratch*\" . popup))
-                            :regexps '((\"^\\*foo\" . terminal)))"
+                            :names \\='((\"*scratch*\" . popup))
+                            :regexps \\='((\"^\\*foo\" . terminal)))"
   (setq purpose-user-mode-purposes (append modes purpose-user-mode-purposes)
         purpose-user-name-purposes (append names purpose-user-name-purposes)
         purpose-user-regexp-purposes (append regexps purpose-user-regexp-purposes))
@@ -447,9 +447,9 @@ This function calls `purpose-compile-user-configuration' to
 update user purposes.
 
 Example:
- (purpose-remove-user-purposes :modes '(org-mode help-mode)
-                               :names '(\"*scratch*\")
-                               :regexps '(\"^\\*foo\"))"
+ (purpose-remove-user-purposes :modes \\='(org-mode help-mode)
+                               :names \\='(\"*scratch*\")
+                               :regexps \\='(\"^\\*foo\"))"
   ;; let-bind before setq-ing, so we don't apply partial changes if one
   ;; of MODES, NAMES or REGEXPS is malformed
   (let ((new-modes (cl-set-difference purpose-user-mode-purposes modes
