@@ -66,13 +66,14 @@ This variable is used by `purpose-window-params'.  See
 
 (defcustom purpose-set-window-properties-functions nil
   "Hook to run after calling `purpose-set-window-properties'.
-Use this to set additional properties for windows as they are created,
-when `purpose-set-window-layout' or `purpose-load-window-layout-file' is called.  Each
-function in `purpose-set-window-properties-functions' is called with two
-arguments: PROPERTIES and WINDOW.  PROPERTIES is the window's property
-list as saved in the used layout, and WINDOW is the new window.  If
-WINDOW is nil, your function should act on the selected window
-instead."
+Use this to set additional properties for windows as they are
+created, when `purpose-set-window-layout' or
+`purpose-load-window-layout-file' is called.  Each function in
+`purpose-set-window-properties-functions' is called with two
+arguments: PROPERTIES and WINDOW.  PROPERTIES is the window's
+property list as saved in the used layout, and WINDOW is the new
+window.  If WINDOW is nil, your function should act on the
+selected window instead."
   :group 'purpose
   :type 'hook
   :package-version '(window-purpose . "1.2"))
@@ -160,8 +161,8 @@ not defined."
                  :width (purpose--window-width-to-percentage window)
                  :height (purpose--window-height-to-percentage window)
                  :edges (purpose--window-edges-to-percentage window))
-           (mapcar #'(lambda (fn)
-                       (funcall fn window))
+           (mapcar (lambda (fn)
+                     (funcall fn window))
                    purpose-get-extra-window-params-functions))))
 
 (defun purpose-set-window-properties (properties &optional window)
@@ -612,11 +613,11 @@ Use INDEX=0 for most recent."
 (defun purpose-delete-non-dedicated-windows ()
   "Delete all windows that aren't dedicated to their purpose or buffer."
   (interactive)
-  (mapc #'(lambda (window)
-            (when (and (window-deletable-p window)
-                       (not (window-dedicated-p window))
-                       (not (purpose-window-purpose-dedicated-p window)))
-              (delete-window window)))
+  (mapc (lambda (window)
+          (when (and (window-deletable-p window)
+                     (not (window-dedicated-p window))
+                     (not (purpose-window-purpose-dedicated-p window)))
+            (delete-window window)))
         (window-list)))
 
 ;;;###autoload
