@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "window-purpose" "1.8.1"
+(define-package "window-purpose" "20241207.148"
   "Purpose-based window management for Emacs."
-  '((emacs      "24.4")
+  '((emacs      "25.1")
     (let-alist  "1.0.3")
     (imenu-list "0.1"))
   :url "https://github.com/bmag/emacs-purpose"
-  :commit "bb462f12f836414425edac32ebd069b4fd5b98d4"
-  :revdesc "bb462f12f836"
+  :commit "c827f45cd9b278b3eb9c2f4bcb55ef2fca5d3048"
+  :revdesc "c827f45cd9b2"
   :keywords '("frames"))
