@@ -224,6 +224,15 @@ the purpose PURPOSE."
   (and (not (window-dedicated-p window))
        (eql purpose (purpose-window-purpose window))))
 
+(defun purpose--frame-list ()
+  "Return a list of all live frames.
+Similar to `frame-list', the only difference being that the
+initial, hidden, frame which is kept around when Emacs is run as
+a daemon is excluded."
+  (if (daemonp)
+      (delq terminal-frame (frame-list))
+    (frame-list)))
+
 (defun purpose--reusable-frames (alist)
   "Return a list of reusable frames.
 If ALIST contains a `reusable-frames' entry, its value determines which
@@ -250,11 +259,11 @@ terminal if it's non-nil."
              (visible-frame-list))
             ((eql reusable-frames 0)
              (cl-remove-if-not
-              #'(lambda (frame)
-                  (eql (frame-terminal frame) (frame-terminal)))
-              (frame-list)))
+              (lambda (frame)
+                (eql (frame-terminal frame) (frame-terminal)))
+              (purpose--frame-list)))
             ((eql reusable-frames t)
-             (frame-list))
+             (purpose--frame-list))
             (t
              (message "Bad value for reusable-frames in ALIST: %S"
                       reusable-frames)
@@ -292,8 +301,8 @@ that frame."
            (windows (purpose-flatten (mapcar #'window-list frames)))
            window)
       (setq windows (cl-delete-if-not
-                     #'(lambda (window)
-                         (purpose-window-buffer-reusable-p window buffer))
+                     (lambda (window)
+                       (purpose-window-buffer-reusable-p window buffer))
                      windows))
       (when .inhibit-same-window
         (setq windows (delq (selected-window) windows)))
@@ -332,8 +341,8 @@ that a window on another frame is chosen, avoid raising that frame."
            (purpose (or purpose (purpose-buffer-purpose buffer)))
            window)
       (setq windows (cl-delete-if-not
-                     #'(lambda (window)
-                         (purpose-window-purpose-reusable-p window purpose))
+                     (lambda (window)
+                       (purpose-window-purpose-reusable-p window purpose))
                      windows))
       (when .inhibit-same-window
         (setq windows (delq (selected-window) windows)))
@@ -369,8 +378,8 @@ that frame."
          (windows (purpose-flatten (mapcar #'window-list frames)))
          window)
     (setq windows (cl-delete-if-not
-                   #'(lambda (window)
-                       (purpose-window-buffer-reusable-p window buffer))
+                   (lambda (window)
+                     (purpose-window-buffer-reusable-p window buffer))
                    windows))
     (setq window (car windows))
     (when window
@@ -409,8 +418,8 @@ that a window on another frame is chosen, avoid raising that frame."
          (purpose (or purpose (purpose-buffer-purpose buffer)))
          window)
     (setq windows (cl-delete-if-not
-                   #'(lambda (window)
-                       (purpose-window-purpose-reusable-p window purpose))
+                   (lambda (window)
+                     (purpose-window-purpose-reusable-p window purpose))
                    windows))
     (setq window (car windows))
     (when window
@@ -450,13 +459,13 @@ Possible windows to use match these requirements:
 
 FRAME defaults to the selected frame."
   (cl-remove-if-not
-   #'(lambda (window)
-       (and (or (not (window-dedicated-p window))
-                (eql (window-buffer window) buffer))
-            (or (not (purpose-window-purpose-dedicated-p window))
-                (eql (purpose-window-purpose window)
-                     (purpose-buffer-purpose buffer)))
-            (not (window-minibuffer-p window))))
+   (lambda (window)
+     (and (or (not (window-dedicated-p window))
+              (eql (window-buffer window) buffer))
+          (or (not (purpose-window-purpose-dedicated-p window))
+              (eql (purpose-window-purpose window)
+                   (purpose-buffer-purpose buffer)))
+          (not (window-minibuffer-p window))))
    (window-list frame)))
 
 (defun purpose-display-maybe-other-window (buffer alist)
@@ -487,9 +496,9 @@ This function doesn't raise the new frame."
   (let-alist alist
     (let* ((windows (purpose-flatten
                      (mapcar
-                      #'(lambda (frame)
+                      (lambda (frame)
                           (purpose-display--frame-usable-windows frame buffer))
-                      (remove (selected-frame) (frame-list)))))
+                      (remove (selected-frame) (purpose--frame-list)))))
            (window (car windows)))
       (when window
         (purpose-change-buffer buffer window 'reuse alist)
@@ -649,7 +658,7 @@ the new window is specified by `purpose-display-at-top-height'.  If
 have the default height."
   (purpose-display--at
    #'purpose-get-top-window
-   #'(lambda ()
+   (lambda ()
        (let* ((height (purpose--normalize-height
                        (or height
                            purpose-display-at-top-height)))
@@ -672,7 +681,7 @@ If `purpose-display-at-bottom-height' is also nil, then the new window
 will have the default height."
   (purpose-display--at
    #'purpose-get-bottom-window
-   #'(lambda ()
+   (lambda ()
        (let* ((height (purpose--normalize-height
                        (or height
                            purpose-display-at-bottom-height)))
@@ -694,7 +703,7 @@ new window is specified by `purpose-display-at-left-width'.  If
 have the default width."
   (purpose-display--at
    #'purpose-get-left-window
-   #'(lambda ()
+   (lambda ()
        (let* ((width (purpose--normalize-width
                       (or width
                           purpose-display-at-left-width)))
@@ -716,7 +725,7 @@ the new window is specified by `purpose-display-at-right-width'.  If
 have the default width."
   (purpose-display--at
    #'purpose-get-right-window
-   #'(lambda ()
+   (lambda ()
        (let* ((width (purpose--normalize-width
                       (or width
                           purpose-display-at-right-width)))
@@ -1109,12 +1118,12 @@ and EXTRA-ARGS, like so:
   (apply display-fn buffer alist extra-args).
 
 Example of how this macro might be used:
-  (defalias 'display-at-bottom-and-dedicate
+  (defalias \\='display-at-bottom-and-dedicate
             (purpose-generate-display-and-dedicate
-             'purpose-display-at-bottom))
+             \\='purpose-display-at-bottom))
 Another example:
   (add-to-list purpose-special-action-sequences
-               `(terminal ,(purpose-generate-display-and-dedicate
+               \\=`(terminal ,(purpose-generate-display-and-dedicate
                             purpose-display-at-bottom 6)))"
   (declare (indent defun) (debug (function-form &rest sexp)))
   `(lambda (buffer alist)
@@ -1135,9 +1144,9 @@ The lambda returns the window used for display, or nil if display was
 unsuccessful.
 
 Possible usage:
-  (defalias 'display-at-left-and-do-stuff
+  (defalias \\='display-at-left-and-do-stuff
             (purpose-generate-display-and-do
-              'purpose-display-at-left
+              \\='purpose-display-at-left
               (lambda (window) (message \"Let's do stuff!!\"))))"
   (declare (indent defun) (debug (function-form function-form)))
   `(lambda (buffer alist)
