@@ -65,14 +65,13 @@
     (:purpose ilist :purpose-dedicated t :width 0.15333333333333332 :height 0.9722222222222222 :edges
               (0.8266666666666667 0.0 1.0133333333333334 0.9722222222222222)))
   "Window layout for purpose-x-code1-dired-ibuffer.
-Has a main 'edit window, and two side windows - 'dired and 'buffers.
+Has a main `edit' window, and two side windows - `dired' and `buffers'.
 All windows are purpose-dedicated.")
 
 ;; the name arg ("purpose-x-code1") is necessary for Emacs 24.5 and older
 ;; (omitting it produces an "Invalid slot name" error)
 (defvar purpose-x-code1-purpose-config
-  (purpose-conf "purpose-x-code1"
-                :mode-purposes
+  (purpose-conf :mode-purposes
                 '((ibuffer-mode . buffers)
                   (dired-mode . dired)
                   (imenu-list-major-mode . ilist))))
@@ -88,8 +87,8 @@ All windows are purpose-dedicated.")
 (defun purpose-x-code1--setup-ibuffer ()
   "Set up ibuffer settings."
   (add-hook 'ibuffer-mode-hook
-            #'(lambda ()
-                (ibuffer-filter-by-purpose-x-code1-ibuffer-files-only nil)))
+            (lambda ()
+              (ibuffer-filter-by-purpose-x-code1-ibuffer-files-only nil)))
   (add-hook 'ibuffer-mode-hook #'ibuffer-auto-mode)
   (setq ibuffer-formats '((mark " " name)))
   (setq ibuffer-display-summary nil)
@@ -104,8 +103,8 @@ All windows are purpose-dedicated.")
 (defun purpose-x-code1--unset-ibuffer ()
   "Unset ibuffer settings."
   (remove-hook 'ibuffer-mode-hook
-               #'(lambda ()
-                   (ibuffer-filter-by-purpose-x-code1-ibuffer-files-only nil)))
+               (lambda ()
+                 (ibuffer-filter-by-purpose-x-code1-ibuffer-files-only nil)))
   (remove-hook 'ibuffer-mode-hook #'ibuffer-auto-mode)
   (setq ibuffer-formats '((mark modified read-only " "
                                 (name 18 18 :left :elide)
@@ -122,10 +121,10 @@ All windows are purpose-dedicated.")
 
 (defun purpose-x-code1-update-dired ()
   "Update free dired window with current buffer's directory.
-If a non-buffer-dedicated window with purpose 'dired exists, display
-the directory of the current buffer in that window, using `dired'.
-If there is no window available, do nothing.
-If current buffer doesn't have a filename, do nothing."
+If a non-buffer-dedicated window with purpose `dired' exists,
+display the directory of the current buffer in that window, using
+`dired'.  If there is no window available, do nothing.  If
+current buffer doesn't have a filename, do nothing."
   (when (and (buffer-file-name)
              (cl-delete-if #'window-dedicated-p
                            (purpose-windows-with-purpose 'dired)))
@@ -149,13 +148,13 @@ buffer had changed."
 (defun purpose-x-code1-setup ()
   "Setup purpose-x-code1.
 This setup includes 4 windows:
-1. dedicated 'edit window
-2. dedicated 'dired window.  This window shows the current buffer's
+1. dedicated `edit' window
+2. dedicated `dired' window.  This window shows the current buffer's
 directory in a special window, using `dired' and
 `dired-hide-details-mode' (if available).
-3. dedicated 'buffers window.  This window shows the currently open
+3. dedicated `buffers' window.  This window shows the currently open
 files, using `ibuffer'.
-4. dedicated 'ilist window.  This window shows the current buffer's
+4. dedicated `ilist' window.  This window shows the current buffer's
 imenu."
   (interactive)
   (purpose-set-extension-configuration :purpose-x-code1 purpose-x-code1-purpose-config)
@@ -190,29 +189,26 @@ imenu."
 ;;; - `purpose-x-magit-multi-on'
 ;;; - `purpose-x-magit-off'
 
+(defvar magit-display-buffer-function)
+
 (defvar purpose-x-magit-single-conf
-  (purpose-conf "magit-single"
-                ;; using `magit' as a condition in
-                ;; `purpose-special-action-sequences' is interpreted
-                ;; as a predicate function (for buffer's without a
-                ;; `magit' purpose). `Magit' doesn't have the same
-                ;; problem (no function is named Magit), so that's why
-                ;; we call the purpose `Magit' and not `magit'.
-                :mode-purposes '((magit-mode . Magit)))
+  ;; using `magit' as a condition in `purpose-special-action-sequences' is
+  ;; interpreted as a predicate function (for buffer's without a `magit'
+  ;; purpose). `Magit' doesn't have the same problem (no function is named
+  ;; Magit), so that's why we call the purpose `Magit' and not `magit'.
+  (purpose-conf :mode-purposes '((magit-mode . Magit)))
   "Configuration that gives each magit major mode the same purpose.")
 
 (defvar purpose-x-magit-multi-conf
   (purpose-conf
-   "magit-multi"
    :mode-purposes '((magit-diff-mode . magit-diff)
                     (magit-status-mode . magit-status)
                     (magit-log-mode . magit-log)
-                    (magit-commit-mode . magit-commit)
+                    (git-commit-mode . magit-commit)
                     (magit-cherry-mode . magit-cherry)
-                    (magit-branch-manager-mode . magit-branch-manager)
+                    (magit-refs-mode . magit-refs)
                     (magit-process-mode . magit-process)
-                    (magit-reflog-mode . magit-reflog)
-                    (magit-wazzup-mode . magit-wazzup)))
+                    (magit-reflog-mode . magit-reflog)))
   "Configuration that gives each magit major mode its own purpose.")
 
 (defvar purpose-x-old-magit-display-buffer-function nil
@@ -272,6 +268,8 @@ invoked.")
 ;;; Make `purpose-mode' and `golden-ratio-mode' work together properly.
 ;;; Basically, this adds a hook to `purpose-select-buffer-hook' so
 ;;; `golden-ratio' is called when a buffer is selected via Purpose.
+(defvar golden-ratio-mode)
+(declare-function golden-ratio "ext:golden-ratio")
 
 (defun purpose-x-sync-golden-ratio ()
   "Add/remove `golden-ratio' to `purpose-select-buffer-hook'.
@@ -305,6 +303,8 @@ Add `golden-ratio' at the end of `purpose-select-buffer-hook' if
 ;;; `purpose-switch-buffer-with-purpose'.
 ;;; This requires package `popup-switcher'
 
+(declare-function psw-switcher "ext:popup-switcher")
+
 (when (require 'popup-switcher nil t)
   (defun purpose-x-psw-switch-buffer-with-purpose ()
     "Use `psw-switcher' to open another buffer with the current purpose."
@@ -324,7 +324,7 @@ Add `golden-ratio' at the end of `purpose-select-buffer-hook' if
 
 (defcustom purpose-x-popwin-position 'bottom
   "Position for the popup window.
-Legal values for this variable are 'top, 'bottom, 'left and 'right.  It
+Legal values for this variable are `top', `bottom', `left' and `right.'  It
 is also possible to set this variable to a function.  That function will
 be used to create new popup windows and should be a display function
 compatible with `display-buffer'."
@@ -362,9 +362,9 @@ When changing the value of this variable in elisp code, you should call
 `purpose-x-popwin-update-conf' for the change to take effect."
   :group 'purpose
   :type '(repeat symbol)
-  :set #'(lambda (symbol value)
-           (prog1 (set-default symbol value)
-             (purpose-x-popwin-update-conf)))
+  :set (lambda (symbol value)
+         (prog1 (set-default symbol value)
+           (purpose-x-popwin-update-conf)))
   :initialize 'custom-initialize-default
   :package-version '(window-purpose . "1.4"))
 
@@ -376,9 +376,9 @@ When changing the value of this variable in elisp code, you should call
 `purpose-x-popwin-update-conf' for the change to take effect."
   :group 'purpose
   :type '(repeat string)
-  :set #'(lambda (symbol value)
-           (prog1 (set-default symbol value)
-             (purpose-x-popwin-update-conf)))
+  :set (lambda (symbol value)
+         (prog1 (set-default symbol value)
+           (purpose-x-popwin-update-conf)))
   :initialize 'custom-initialize-default
   :package-version '(window-purpose . "1.4"))
 
@@ -390,9 +390,9 @@ When changing the value of this variable in elisp code, you should call
 `purpose-x-popwin-update-conf' for the change to take effect."
   :group 'purpose
   :type '(repeat string)
-  :set #'(lambda (symbol value)
-           (prog1 (set-default symbol value)
-             (purpose-x-popwin-update-conf)))
+  :set (lambda (symbol value)
+         (prog1 (set-default symbol value)
+           (purpose-x-popwin-update-conf)))
   :initialize 'custom-initialize-default
   :package-version '(window-purpose . "1.4"))
 
@@ -423,7 +423,6 @@ The configuration is updated according to
   (interactive)
   (cl-flet ((joiner (x) (cons x 'popup)))
     (let ((conf (purpose-conf
-                 "popwin"
                  :mode-purposes (mapcar #'joiner purpose-x-popwin-major-modes)
                  :name-purposes (mapcar #'joiner purpose-x-popwin-buffer-names)
                  :regexp-purposes (mapcar #'joiner
@@ -434,10 +433,10 @@ The configuration is updated according to
   "Return function for creating new popup windows.
 The function is determined by the value of `purpose-x-popwin-position'."
   (or (cl-case purpose-x-popwin-position
-        ('top 'purpose-display-at-top)
-        ('bottom 'purpose-display-at-bottom)
-        ('left 'purpose-display-at-left)
-        ('right 'purpose-display-at-right))
+        (top 'purpose-display-at-top)
+        (bottom 'purpose-display-at-bottom)
+        (left 'purpose-display-at-left)
+        (right 'purpose-display-at-right))
       (and (functionp purpose-x-popwin-position)
            purpose-x-popwin-position)
       (user-error "purpose-x-popwin-position has an invalid value: %S"
@@ -459,7 +458,7 @@ See `display-buffer' for the meaning of ALIST."
 (defun purpose-x-popwin-close-windows ()
   "Delete all popup windows.
 Internally, this function works be deleting all windows that have the
-'popup purpose.  It also buried all popup buffers so they don't bother
+`popup' purpose.  It also buried all popup buffers so they don't bother
 the user when switching buffers."
   (interactive)
   (mapc #'delete-window (purpose-windows-with-purpose 'popup))
@@ -565,6 +564,11 @@ Look at `purpose-x-popwin-*' variables and functions to learn more."
 ;;; purpose and perspective as the current buffer
 ;;; (`purpose-x-persp-switch-buffer', `*-other-windw', `*-other-frame').
 
+(defvar persp-mode)
+(declare-function persp-buffers "ext:persp-mode")
+(declare-function persp-name "ext:persp-mode")
+(declare-function get-current-persp "ext:persp-mode")
+
 (defvar purpose-x-persp-confs (make-hash-table :test 'equal)
   "Hash table holding perspectives' purpose configurations.
 The table maps a perspective's name to its purpose configuration.  A
@@ -576,7 +580,7 @@ To add/remove entries, use:
 
 (defun purpose-x-persp-activate ()
   "Activate current perspective's purpose configuration."
-  (let ((conf (gethash (persp-name (persp-curr)) purpose-x-persp-confs)))
+  (let ((conf (gethash (persp-name (get-current-persp)) purpose-x-persp-confs)))
     (if conf
         (purpose-set-extension-configuration :perspective conf)
       (purpose-x-persp-remove))))
@@ -618,7 +622,7 @@ purpose configurations."
 (defun purpose-x-persp-get-buffer-names ()
   "Get names of all buffers with same purpose and perspective as current buffer.
 The returned list doesn't contain the current buffer."
-  (let ((persp-buffers (persp-buffers (persp-curr))))
+  (let ((persp-buffers (persp-buffers (get-current-persp))))
     (mapcar #'buffer-name
             (cl-delete-if-not (lambda (buffer) (member buffer persp-buffers))
                               (delete (current-buffer)
